@@ -1,14 +1,13 @@
 from datetime import datetime
-from typing import List, Union
+from typing import Any, Dict, List, Tuple, Union
 
 import pandas as pd
 
 from archimedes.data.common import get_api_base_url_v2
-from archimedes.utils import get_end_date, get_start_date
 from archimedes.utils.api_request import api
+from archimedes.utils.date import datetime_to_iso_format, get_end_date, get_start_date
 from archimedes.utils.split import get_queries_observation, get_queries_observation_json
 from archimedes.utils.threaded_executor import execute_many
-from archimedes.utils.utils import datetime_to_iso_format
 
 
 def get(  # pylint:disable=too-many-locals
@@ -18,7 +17,8 @@ def get(  # pylint:disable=too-many-locals
     end: Union[str, pd.Timestamp, datetime, None] = None,
     *,
     access_token: str = None,
-):
+    **kwargs,
+) -> pd.DataFrame:
     """Get any number of time series.
 
     This function can be used to fetch time series from the Archimedes Database.
@@ -72,7 +72,9 @@ def get(  # pylint:disable=too-many-locals
     end = datetime_to_iso_format(get_end_date(end))
 
     observation_series_ids, observation_json_series_ids = _split_series_ids(
-        series_ids, access_token
+        series_ids,
+        access_token,
+        **kwargs,
     )
 
     queries_by_type = {
@@ -92,6 +94,7 @@ def get(  # pylint:disable=too-many-locals
             f"{get_api_base_url_v2()}/{request_url_path}/get",
             params=params,
             access_token=access_token,
+            **kwargs,
         )
         return request_type, query_result
 
@@ -144,7 +147,7 @@ def get_latest(
     price_areas: List[str] = None,
     *,
     access_token: str = None,
-):
+) -> pd.DataFrame:
     """Get the most recent data for any number of time series.
 
     This function is similar to `get()`, but only fetches data from the past 48 hours,
@@ -198,14 +201,19 @@ def get_latest(
     return df
 
 
-def _split_series_ids(series_ids, access_token=None):
+def _split_series_ids(
+    series_ids: List[str], access_token: str = None, **kwargs
+) -> Tuple[List[str], List[str]]:
     base_url = get_api_base_url_v2()
     all_series_ids_observations = api.request(
-        f"{base_url}/data/list_ids", access_token=access_token
+        f"{base_url}/data/list_ids",
+        access_token=access_token,
+        **kwargs,
     )
     all_series_ids_observations_json = api.request(
         f"{base_url}/observation_json/list_ids",
         access_token=access_token,
+        **kwargs,
     )
     series_ids_observations = [
         series_id
@@ -231,7 +239,7 @@ def _split_series_ids(series_ids, access_token=None):
     return series_ids_observations, series_ids_observations_json
 
 
-def _process_observations(observations):
+def _process_observations(observations: Dict[str, Any]) -> pd.DataFrame:
     observations = pd.DataFrame(observations)
     if not observations.empty:
         observations = observations.sort_values(by=["from_dt", "version"]).pivot_table(
@@ -243,8 +251,8 @@ def _process_observations(observations):
     return observations
 
 
-def _process_observations_json(observations):
-    observations_json = pd.DataFrame(observations)
+def _process_observations_json(observations_json: Dict[str, Any]) -> pd.DataFrame:
+    observations_json = pd.DataFrame(observations_json)
     if not observations_json.empty:
         is_intraday_trades = observations_json["series_id"] == "NP/IntradayTrades"
 
