@@ -12,7 +12,7 @@ from requests.exceptions import (  # pylint:disable=redefined-builtin
     JSONDecodeError,
     Timeout,
 )
-from retry import retry
+from retry.api import retry_call
 
 from archimedes import NoneAuth, get_auth
 from archimedes.configuration import get_api_timeout
@@ -28,10 +28,18 @@ class ArchimedesApi:  # pylint:disable=too-few-public-methods
     def __init__(self):
         self.session = requests.Session()
 
-    @retry(RETRY_EXCEPTIONS, tries=3, delay=2)
-    def request(self, url, method="GET", access_token=None, **kwargs):
+    def request(  # pylint:disable=too-many-arguments
+        self,
+        url,
+        method="GET",
+        access_token=None,
+        retry_count=3,
+        retry_delay=2,
+        **kwargs,
+    ):
         """
-        Make request to the Archimedes API. It automatically retries 3 times on failure.
+        Make request to the Archimedes API. It automatically retries retry_count times
+        on failure.
 
         Args:
             url:
@@ -41,11 +49,15 @@ class ArchimedesApi:  # pylint:disable=too-few-public-methods
             access_token:
                 authorization token; if None, tries to get the token automatically based
                 on the authentication configuration.
+            retry_count:
+                number of times to retry the request.
+            retry_delay:
+                delay between retries in seconds.
             **kwargs:
                 other kwargs to requests.request.
 
         Returns:
-            JSON response
+            Response from the API as a python object.
         """
         if access_token is None:
             archimedes_auth = get_auth()
@@ -57,12 +69,18 @@ class ArchimedesApi:  # pylint:disable=too-few-public-methods
             access_token = archimedes_auth.get_access_token_silent()
 
         timeout = kwargs.pop("timeout", get_api_timeout())
-        kwargs["timeout"] = timeout
 
         headers = kwargs.pop("headers", {})
-
         headers.update({"Authorization": f"Bearer {access_token}"})
-        response = self.session.request(method, url, headers=headers, **kwargs)
+
+        response = retry_call(
+            self.session.request,
+            fargs=(method, url),
+            fkwargs=dict(headers=headers, timeout=timeout, **kwargs),
+            tries=retry_count,
+            delay=retry_delay,
+            exceptions=RETRY_EXCEPTIONS,
+        )
 
         if response.status_code not in [HTTPStatus.OK, HTTPStatus.CREATED]:
             try:
